PyTessel: isosurface generation tool
====================================

.. image:: https://anaconda.org/ifilot/pydft/badges/version.svg
   :target: https://anaconda.org/ifilot/pydft
.. image:: https://img.shields.io/pypi/v/pydft?color=green
   :target: https://pypi.org/project/pydft/
.. image:: https://github.com/ifilot/pydft/actions/workflows/build.yml/badge.svg
   :target: https://github.com/ifilot/pydft/actions/workflows/build.yml
.. image:: https://img.shields.io/badge/License-GPLv3-blue.svg
   :target: https://www.gnu.org/licenses/gpl-3.0

:program:`PyDFT` is a Python package for performing DFT calculations.

:program:`PyDFT` has been developed at the Eindhoven University of Technology,
Netherlands. :program:`PyTessel` and its development are hosted on `github
<https://gitlab.tue.nl/ifilot/pydft>`_.  Bugs and feature
requests are ideally submitted via the `github issue tracker
<https://gitlab.tue.nl/ifilot/pydft/issues>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   background
   user_interface
   examples
   community_guidelines

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`
